@@ -58,7 +58,7 @@ def main(passed_args=None):
     ui = UI()
 
     loop = asyncio.get_event_loop()
-#    loop.set_debug(True)
+    loop.set_debug(True)
     loop.set_default_executor(concurrent.futures.ThreadPoolExecutor(20))
 
     try:
