@@ -11,9 +11,6 @@ class DOIChecker(object):
         self._cfg = Config()
 
     async def check(self, entry):
-        if not self._cfg.get('check_{}'.format(type(self).NAME), entry, True):
-            return []
-
         doi = entry.data.get('doi')
         if not doi:
             suggested_doi = entry.get_doi()
@@ -37,9 +34,6 @@ class DOIURLChecker(object):
         self._cfg = Config()
 
     async def check(self, entry):
-        if not self._cfg.get('check_{}'.format(type(self).NAME), entry, True):
-            return []
-
         url = entry.data.get('url')
         problems = []
         if not url:
@@ -59,21 +53,23 @@ class DeadURLChecker(object):
         self._cfg = Config()
 
     async def check(self, entry):
-        if not self._cfg.get('check_{}'.format(type(self).NAME), entry, True):
-            return []
-
         url = entry.data.get('url')
         problems = []
         if not url:
             return []
 
-        async with aiohttp.ClientSession() as session:
-            async with session.get(url) as resp:
-                status = resp.status
-                if status >= 400 or status < 200:
-                    problems.append((type(self).NAME, "URL seems inaccessible",
-                                     "Accessing URL '{}' gives status code {}"
-                                     .format(url, status)))
+        try:
+            async with aiohttp.ClientSession() as session:
+                async with session.get(url) as resp:
+                    status = resp.status
+                    if status >= 400 or status < 200:
+                        problems.append((type(self).NAME, "URL seems inaccessible",
+                                         "Accessing URL '{}' gives status code {}"
+                                         .format(url, status)))
+
+        except aiohttp.client_exceptions.ClientConnectorError as e:
+            problems.append((type(self).NAME, "Could not connect to host",
+                             f"Could not connect to the host for URL {url}."))
 
         return problems
 
@@ -85,9 +81,6 @@ class RequiredFieldsChecker(object):
         self._cfg = Config()
 
     async def check(self, entry):
-        if not self._cfg.get('check_{}'.format(type(self).NAME), entry, True):
-            return []
-
         problems = []
 
         required_fields = self._cfg.get('required', entry)
@@ -122,9 +115,6 @@ class ForbiddenFieldsChecker(object):
         self._cfg = Config()
 
     async def check(self, entry):
-        if not self._cfg.get('check_{}'.format(type(self).NAME), entry, True):
-            return []
-
         problems = []
 
         forbidden_fields = self._cfg.get('forbidden_fields', entry, [])
